@@ -7,9 +7,31 @@ Cite as: `Astrophysics Source Code Library, record ascl:1112.014
 
 This package can load and use a Jet Propulsion Laboratory (JPL)
 ephemeris for predicting the position and velocity of a planet or other
-Solar System body.  It only needs `NumPy <http://www.numpy.org/>`_,
-which ``pip`` will automatically attempt to install alongside
-``pyephem`` when you run::
+Solar System body.  It currently supports binary SPK files (extension
+``.bsp``) like `those distributed by the Jet Propulsion Laboratory
+<https://ssd.jpl.nasa.gov/ftp/eph/planets/bsp/>`_ that are:
+
+* **Type 2** — positions stored as Chebyshev polynomials, with velocity
+  derived by computing their derivative.
+
+* **Type 3** — positions and velocities both stored explicitly as
+  Chebyshev polynomials.
+
+* **Type 9** — a series of discrete positions and velocities, with
+  separate timestamps that do not need to be equally spaced.  Currently
+  there is only support for linear interpolation: for Type 9 ephemerides
+  of polynomial degree 1, not of any higher degrees.
+
+Note that even if an ephemeris isn’t one of the above types, you can
+still use ``jplephem`` to read its text comment and list the segments
+inside, using the subcommands ``comment`` and ``daf`` described below.
+
+Installation
+------------
+
+The only third-party package that ``jplephem`` depends on is `NumPy
+<http://www.numpy.org/>`_, which ``pip`` will automatically attempt to
+install alongside ``pyephem`` when you run::
 
     $ pip install jplephem
 
@@ -51,6 +73,13 @@ limiting the range of dates that it covers::
 
     python -m jplephem excerpt 2018/1/1 2018/4/1 de421.bsp excerpt421.bsp
 
+You will get an error if your starting year is negative, because Unix
+commands expect a list of options when they see a dash.  The fix is to
+provide a special argument ``--`` which says “I’m done passing options,
+even if the next argument stars with a dash”::
+
+    python -m jplephem excerpt -- -800/1/1 800/1/1 de422.bsp excerpt422.bsp
+
 You can also filter by the integer codes for the targets you need.
 Unrecognized targets will not raise an error, to let you apply a master
 list of targets to a whole series of SPK files that might or might not
@@ -58,12 +87,12 @@ each have all of the targets::
 
     python -m jplephem excerpt --targets 1,2,3 2018/1/1 2018/4/1 de421.bsp excerpt421.bsp
 
-If the input ephemeris is a URL, then `jplephem` will try to save
+If the input ephemeris is a URL, then ``jplephem`` will try to save
 bandwidth by fetching only the blocks of the remote file that are
 necessary to cover the dates you have specified.  For example, the
-Jupiter satellite ephemeris `jup310.bsp` is famously large, weighing in
-a nearly a gigabyte.  But if all you need are Jupiter's satellites for a
-few months, you can download considerably less data::
+Jupiter satellite ephemeris ``jup310.bsp`` is famously large, weighing
+in a nearly a gigabyte.  But if all you need are Jupiter's satellites
+for a few months, you can download considerably less data::
 
     $ python -m jplephem excerpt 2018/1/1 2018/4/1 \\
         https://naif.jpl.nasa.gov/pub/naif/generic_kernels/spk/satellites/jup310.bsp \\
@@ -111,10 +140,11 @@ make vector output attractive.
 >>> import numpy as np
 >>> np.set_printoptions(precision=3)
 
-Each segment of the file lets you predict the position of an object with
-respect to some other reference point.  If you want the coordinates of
-Mars at 2457061.5 (2015 February 8) with respect to the center of the
-solar system, this ephemeris only requires you to take a single step:
+Each segment of the file lets you predict the position of one body with
+respect to another.  For example, here are the coordinates of Mars (4)
+with respect to the Solar System barycenter (0) at midnight 2015
+February 8 TDB (Barycentric Dynamical Time) which is Julian date
+2457061.5:
 
 >>> position = kernel[0,4].compute(2457061.5)
 >>> print(position)
@@ -130,9 +160,9 @@ barycenter and finally to Earth itself:
 >>> print(position)
 [ 3.161e+08 -4.679e+07 -2.476e+07]
 
-You can see that the output of this ephemeris is in kilometers.  If you
-use another ephemeris, check its documentation to be sure of the units
-that it employs.
+You can see that the output of this ephemeris DE421 is in kilometers.
+If you use another ephemeris, check its documentation to be sure of the
+units that it employs.
 
 If you supply the date as a NumPy array, then each component that is
 returned will itself be a vector as long as your date:
@@ -301,51 +331,14 @@ You can ask for velocity as well.
 >>> print(v)
 [6.707e-09 4.838e-10 2.655e-06]
 
-Legacy Ephemeris Packages
--------------------------
+Closing an ephemeris
+--------------------
 
-Back before I learned about SPICE and SPK files, I had run across the
-text-file formatted JPL ephemerides at:
-
-ftp://ssd.jpl.nasa.gov/pub/eph/planets/ascii/
-
-I laboriously assembled the data in these text files into native NumPy
-array files and wrapped them each in a Python package so that users
-could install an ephemeris with a simple command::
-
-    pip install de421
-
-If you want to use one of these pip-installable ephemerides, you will be
-using a slightly older API, and will lose the benefit of the efficient
-memory-mapping that the newer SPK code performs.  With the old API, here
-is how you would load DE421 and compute a position, given a barycentric
-dynamical time expressed as a Julian date::
-
-    import de421
-    from jplephem import Ephemeris
-
-    eph = Ephemeris(de421)
-    x, y, z = eph.position('mars', 2444391.5)  # 1980.06.01
-
-For more information about the legacy API, consult the ``jplephem``
-entry on PyPI for the final release of the 1.x series:
-
-https://pypi.python.org/pypi/jplephem/1.2
-
-The ephemerides that were made available as Python packages (the
-following links explain the differences between them) are:
-
-* `DE405 <http://pypi.python.org/pypi/de405>`_ (May 1997)
-  — 54 MB covering years 1600 through 2200
-* `DE406 <http://pypi.python.org/pypi/de406>`_ (May 1997)
-  — 190 MB covering years -3000 through 3000
-* `DE421 <http://pypi.python.org/pypi/de421>`_ (February 2008)
-  — 27 MB covering years 1900 through 2050
-* `DE422 <http://pypi.python.org/pypi/de422>`_ (September 2009)
-  — 531 MB covering years -3000 through 3000
-* `DE423 <http://pypi.python.org/pypi/de423>`_ (February 2010)
-  — 36 MB covering years 1800 through 2200
+To release all open files and memory maps associated with an ephemeris,
+call its ``close()`` method.
 
+>>> kernel.close()
+>>> p.close()
 
 Reporting issues
 ----------------
@@ -354,15 +347,46 @@ You can report any issues, bugs, or problems at the GitHub repository:
 
 https://github.com/brandon-rhodes/python-jplephem/
 
-
 Changelog
 ---------
 
+**2022 September 6 — Version 2.19**
+
+* Fixed a bug in the ``excerpt`` command that was causing it to truncate
+  its output when the input ephemeris had more than about two dozen
+  segments.  The command’s output should now include all matching
+  segments from even a very large ephemeris.
+
+* Fixed the ``excerpt`` command so the calendar dates specified on the
+  command line produce Julian dates ending with the fraction ``.5``,
+  which makes excerpt endpoints more exact.
+
+**2022 September 28 — Version 2.18**
+
+* Added support for big-endian processors, and created a GitHub Actions
+  CI build that includes both a big- and a little-endian architecture.
+
+**2021 December 31 — Version 2.17**
+
+* Fixed an ``AttributeError`` in the ``excerpt`` command.
+
+**2021 July 3 — Version 2.16**
+
+* Fixed a ``ValueError`` raised in the ``excerpt`` command when an
+  ephemeris segment needs to be entirely skipped because it has no
+  overlap with the user-specified range of dates.
+
+* Added a ``__version__`` constant to the package’s top level.
+
 **2020 September 2 — Version 2.15**
 
 * The ``excerpt`` subcommand now accepts a ``--targets`` option to save
   space by copying only matching segments into the output SPK file.
 
+* The Julian day fraction ``tdb2`` is handled even more carefully than
+  before, providing a smoother delta between successive positions when
+  the difference between successive times is down around 0.1 µs.
+
 **2020 March 26 — Version 2.14**
 
 * Fall back to plain file I/O on platforms that support ``fileno()`` but
@@ -482,7 +506,6 @@ Changelog
 
 * Initial release
 
-
 References
 ----------
 
@@ -499,5 +522,6 @@ FTP site: ftp://ssd.jpl.nasa.gov/pub/eph/planets/fortran/
 
 """
 from .ephem import Ephemeris, DateError
+__version__ = '2.19'
 
-__all__ = ['Ephemeris', 'DateError']
+__all__ = ['Ephemeris', 'DateError', '__version__']
